import { defineConfig } from 'rollup'
import esbuild from 'rollup-plugin-esbuild'
import fs from 'fs'
import path from 'path'
// import typescript from '@rollup/plugin-typescript';
import dts from 'rollup-plugin-dts';


const components = fs
  .readdirSync('src/components')
  .filter(f =>
    fs.statSync(path.join('src/components', f)).isDirectory()
  )

const esbuildOptions = {
  minify: true
}

const external = [
  'vue',
]

const component = (name) =>  [
  // javascript output
  defineConfig({
    plugins: [
      esbuild(esbuildOptions),
    ],
    external,
    input: `src/components/${name}/index.ts`,
    output: {
      format: 'esm',
      file: `dist/components/${name}/index.js`,
    }
  }),
  // .d.ts output
  defineConfig({
    plugins: [dts()],
    input: `src/components/${name}/index.ts`,
    output: {
      format: 'esm',
      file: `dist/components/${name}/index.d.ts`,
    }
  })
]

export default defineConfig([
  ...components.flatMap((name) => component(name)),
  ...[
    defineConfig({
      plugins: [
        esbuild(esbuildOptions)
      ],
      external,
      input: `src/index.ts`,
      output: {
        format: 'esm',
        file: `dist/ritro-ui-vue.esm.js`,
      }
    }),
     // Root .d.ts configuration
    defineConfig({
      plugins: [dts()],
      input: `src/index.ts`,
      output: {
        format: 'esm',
        file: 'dist/ritro-ui-vue.d.ts',
      },
    }),
  ]
])